@@ -8,8 +8,7 @@ DependencyBindingInstance = typing.Any
 DependencyBindingRecord = namedtuple('DependencyBindingRecord', ['type', 'instance', 'scope'])
 DependencyBingingRegistry = collections.abc.MutableMapping[DependencyBindingContract, DependencyBindingRecord]
 
-CallbackRecord = namedtuple('CallbackRecord', ['type', 'instance'])
-CallbackRegistry = collections.abc.MutableMapping[DependencyBindingContract, CallbackRecord]
+CallbackRegistry = collections.abc.MutableMapping[DependencyBindingContract, typing.Callable]
 
 SingletonInstance = typing.Any
 SingletonInstanceRegistry = collections.abc.MutableMapping[DependencyBindingContract, SingletonInstance]
@@ -118,15 +117,10 @@ class DependencyContainer(typing.Protocol):
         event_type: EventType
     ): ...
 
-    def register_success_shutdown_callback(
+    def register_shutdown_callback(
         self,
-        callback: typing.Callable,
-        contract: DependencyBindingContract,
-    ): ...
-
-    def register_failure_shutdown_callback(
-        self,
-        callback: typing.Callable,
+        success_callback: typing.Callable,
+        failure_callback: typing.Callable,
         contract: DependencyBindingContract,
     ): ...
 
